/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.content.targeting.rule.haspressedbutton;

import com.liferay.content.targeting.anonymous.users.model.AnonymousUser;
import com.liferay.content.targeting.api.model.BaseRule;
import com.liferay.content.targeting.api.model.Rule;
import com.liferay.content.targeting.model.RuleInstance;
import com.liferay.content.targeting.rule.categories.SampleRuleCategory;
import com.liferay.portal.kernel.json.JSONException;
import com.liferay.portal.kernel.json.JSONFactoryUtil;
import com.liferay.portal.kernel.json.JSONObject;
import com.liferay.portal.kernel.language.LanguageUtil;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.ParamUtil;

import java.util.Locale;
import java.util.Map;

import javax.portlet.PortletRequest;
import javax.portlet.PortletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;

/**
 * @author Brian Chan
 */
@Component(immediate = true, service = Rule.class)
public class HasPressedButtonRule extends BaseRule {

	@Activate
	@Override
	public void activate() {
		super.activate();
	}

	@Deactivate
	@Override
	public void deActivate() {
		super.deActivate();
	}

	@Override
	public boolean evaluate(
			HttpServletRequest request, RuleInstance ruleInstance,
			AnonymousUser anonymousUser)
		throws Exception {

		HttpSession session = request.getSession();

		if (session == null) {
			return false;
		}

		System.out.println(anonymousUser.getTypeSettings());

		JSONObject jsonObj = JSONFactoryUtil.createJSONObject(
			ruleInstance.getTypeSettings());

		int minPresses = jsonObj.getInt("minPresses", 1);
		int maxPresses = jsonObj.getInt("maxPresses", 0);

		int presses = GetterUtil.getInteger(
			session.getAttribute("LIFERAY_SHARED_PRESSES"), -1);

		if (presses < minPresses) {
			return false;
		}

		if ((maxPresses >= minPresses) && (presses > maxPresses)) {
			return false;
		}

		return true;
	}

	@Override
	public String getIcon() {
		return "icon-hand-up";
	}

	@Override
	public String getRuleCategoryKey() {
		return SampleRuleCategory.KEY;
	}

	@Override
	public String getSummary(RuleInstance ruleInstance, Locale locale) {
		return LanguageUtil.get(locale, ruleInstance.getTypeSettings());
	}

	@Override
	public String processRule(
		PortletRequest request, PortletResponse response, String id,
		Map<String, String> values) {

		// PressesRule.java

		int minPresses = ParamUtil.getInteger(request, "minPresses", 1);
		int maxPresses = ParamUtil.getInteger(request, "maxPresses", 0);

		if (maxPresses < minPresses) {
			maxPresses = 0;
		}

		JSONObject jsonObj = JSONFactoryUtil.createJSONObject();

		jsonObj.put("minPresses", minPresses);
		jsonObj.put("maxPresses", maxPresses);

		return jsonObj.toString();
	}

	@Override
	protected void populateContext(
		RuleInstance ruleInstance, Map<String, Object> context,
		Map<String, String> values) {

		int minPresses = 1;
		int maxPresses = 0;

		if (!values.isEmpty()) {
			minPresses = GetterUtil.getInteger(
				values.get("minPresses"), minPresses);
			maxPresses = GetterUtil.getInteger(
				values.get("maxPresses"), maxPresses);
		}
		else if (ruleInstance != null) {
			try {
				JSONObject jsonObj = JSONFactoryUtil.createJSONObject(
					ruleInstance.getTypeSettings());

				minPresses = jsonObj.getInt("minPresses", minPresses);
				maxPresses = jsonObj.getInt("maxPresses", maxPresses);
			}
			catch (JSONException e) {
			}
		}

		context.put("minPresses", minPresses);
		context.put("maxPresses", maxPresses);
	}

}
